==> yin_webview-0.0.6.tar.gz: lib/YinWebViewPlugin.dart <==
import 'dart:async';

import 'package:flutter/material.dart';
import 'package:flutter/rendering.dart';
import 'package:yin_webview/yin_webview.dart';

class YinWebViewPlugin extends StatefulWidget {
  final String url;
  final List<Widget> actions;
  final Map<String, String> headers;
  final bool withJavascript;
  final bool clearCookies;
  final List<Map<String, String>> cookieList;
  final String userAgent;
  final bool scrollBar;
  final Widget initialChild;
  final Function webTitle;
  final Function loadUrl;
  final Function plugin;

  YinWebViewPlugin({
    key,
    this.url,
    this.actions,
    this.headers,
    this.withJavascript,
    this.clearCookies,
    this.cookieList,
    this.userAgent,
    this.scrollBar,
    this.initialChild,
    this.webTitle,
    this.loadUrl,
    this.plugin,
  }) : super(key: key);

  @override
  YinWebViewPluginState createState() => new YinWebViewPluginState();
}

class YinWebViewPluginState extends State<YinWebViewPlugin> {
  var yinWebView = new YinWebview();
  Rect _rect;
  Timer _resizeTimer;
  String title = "";

  @override
  void initState() {
    super.initState();
    getPlugin();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: new AppBar(
        title: new Text(title),
        centerTitle: true,
        actions: widget.actions ?? [new Container()],
      ),
      body: _WebviewPlaceholder(
        onRectChanged: (Rect value) {
          if (_rect == null) {
            _rect = value;
            yinWebView.launch(
              widget.url,
              rect: _rect,
              headers: widget.headers,
              withJavascript: widget.withJavascript,
              clearCookies: widget.clearCookies,
              cookieList: widget.cookieList,
              userAgent: widget.userAgent,
              scrollBar: widget.scrollBar,
              webTitle: (value) {
                setState(() {
                  title = value;
                });
                if (widget.webTitle != null) {
                  widget.webTitle(value);
                }
              },
              loadUrl: (String value) {
                if (widget.loadUrl(value)) {
                  close();
                }
              },
            );
          } else {
            if (_rect != value) {
              _rect = value;
              _resizeTimer?.cancel();
              _resizeTimer = Timer(const Duration(milliseconds: 250), () {
                yinWebView.resize(_rect);
              });
            }
          }
        },
        child: const Center(child: const CircularProgressIndicator()),
      ),
    );
  }

  void getPlugin() {
    if (widget.plugin != null) {
      widget.plugin(yinWebView);
    }
  }

  void close() {
    if (mounted) {
      Navigator.pop(context);
    }
  }

  @override
  void dispose() {
    super.dispose();
    yinWebView.close();
    _resizeTimer?.cancel();
    yinWebView.dispose();
    yinWebView = null;
    getPlugin();
  }
}

class _WebviewPlaceholder extends SingleChildRenderObjectWidget {
  const _WebviewPlaceholder({
    Key key,
    @required this.onRectChanged,
    Widget child,
  }) : super(key: key, child: child);

  final ValueChanged<Rect> onRectChanged;

  @override
  RenderObject createRenderObject(BuildContext context) {
    return _WebviewPlaceholderRender(onRectChanged: onRectChanged);
  }

  @override
  void updateRenderObject(BuildContext context, _WebviewPlaceholderRender renderObject) {
    renderObject..onRectChanged = onRectChanged;
  }
}

class _WebviewPlaceholderRender extends RenderProxyBox {
  _WebviewPlaceholderRender({RenderBox child, ValueChanged<Rect> onRectChanged})
      : _callback = onRectChanged,
        super(child);

  ValueChanged<Rect> _callback;
  Rect _rect;

  Rect get rect => _rect;

  set onRectChanged(ValueChanged<Rect> callback) {
    if (callback != _callback) {
      _callback = callback;
      notifyRect();
    }
  }

  void notifyRect() {
    if (_callback != null && _rect != null) {
      _callback(_rect);
    }
  }

  @override
  void paint(PaintingContext context, Offset offset) {
    super.paint(context, offset);

    final rect = offset & size;
    if (_rect != rect) {
      _rect = rect;
      notifyRect();
    }
  }
}

==> yin_webview-0.0.7.tar.gz: lib/YinWebViewPlugin.dart <==
import 'dart:async';

import 'package:flutter/material.dart';
import 'package:flutter/rendering.dart';
import 'package:yin_webview/yin_webview.dart';

class YinWebViewPlugin extends StatefulWidget {
  final String url;
  final List<Widget> actions;
  final Map<String, String> headers;
  final bool withJavascript;
  final bool clearCookies;
  final List<Map<String, String>> cookieList;
  final String userAgent;
  final bool scrollBar;
  final Widget initialChild;
  final Function webTitle;
  final Function loadUrl;
  final Function plugin;

  YinWebViewPlugin({
    key,
    this.url,
    this.actions,
    this.headers,
    this.withJavascript,
    this.clearCookies,
    this.cookieList,
    this.userAgent,
    this.scrollBar,
    this.initialChild,
    this.webTitle,
    this.loadUrl,
    this.plugin,
  }) : super(key: key);

  @override
  YinWebViewPluginState createState() => new YinWebViewPluginState();
}

class YinWebViewPluginState extends State<YinWebViewPlugin> {
  var yinWebView = new YinWebview();
  Rect _rect;
  Timer _resizeTimer;
  String title = "";

  @override
  void initState() {
    super.initState();
    getPlugin();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: new AppBar(
        title: new Text(title),
        centerTitle: true,
        actions: widget.actions ?? [new Container()],
      ),
      body: _WebviewPlaceholder(
        onRectChanged: (Rect value) {
          if (_rect == null) {
            _rect = value;
            yinWebView.launch(
              widget.url,
              rect: _rect,
              headers: widget.headers,
              withJavascript: widget.withJavascript,
              clearCookies: widget.clearCookies,
              cookieList: widget.cookieList,
              userAgent: widget.userAgent,
              scrollBar: widget.scrollBar,
              webTitle: (value) {
                setState(() {
                  title = value;
                });
                if (widget.webTitle != null) {
                  widget.webTitle(value);
                }
              },
              loadUrl: (String value) {
                if (widget.loadUrl(value)) {
                  close();
                }
              },
            );
          } else {
            if (_rect != value) {
              _rect = value;
              _resizeTimer?.cancel();
              _resizeTimer = Timer(const Duration(milliseconds: 250), () {
                yinWebView.resize(_rect);
              });
            }
          }
        },
        child: const Center(child: const CircularProgressIndicator()),
      ),
    );
  }

  void getPlugin() {
    if (widget.plugin != null) {
      widget.plugin(yinWebView);
    }
  }

  void close() {
    if (mounted) {
      Navigator.pop(context,true);
    }
  }

  @override
  void dispose() {
    super.dispose();
    yinWebView.close();
    _resizeTimer?.cancel();
    yinWebView.dispose();
    yinWebView = null;
    getPlugin();
  }
}

class _WebviewPlaceholder extends SingleChildRenderObjectWidget {
  const _WebviewPlaceholder({
    Key key,
    @required this.onRectChanged,
    Widget child,
  }) : super(key: key, child: child);

  final ValueChanged<Rect> onRectChanged;

  @override
  RenderObject createRenderObject(BuildContext context) {
    return _WebviewPlaceholderRender(onRectChanged: onRectChanged);
  }

  @override
  void updateRenderObject(BuildContext context, _WebviewPlaceholderRender renderObject) {
    renderObject..onRectChanged = onRectChanged;
  }
}

class _WebviewPlaceholderRender extends RenderProxyBox {
  _WebviewPlaceholderRender({RenderBox child, ValueChanged<Rect> onRectChanged})
      : _callback = onRectChanged,
        super(child);

  ValueChanged<Rect> _callback;
  Rect _rect;

  Rect get rect => _rect;

  set onRectChanged(ValueChanged<Rect> callback) {
    if (callback != _callback) {
      _callback = callback;
      notifyRect();
    }
  }

  void notifyRect() {
    if (_callback != null && _rect != null) {
      _callback(_rect);
    }
  }

  @override
  void paint(PaintingContext context, Offset offset) {
    super.paint(context, offset);

    final rect = offset & size;
    if (_rect != rect) {
      _rect = rect;
      notifyRect();
    }
  }
}
